@@ -59,8 +59,6 @@ webkit_security_origin_get_host     (WebKitSecurityOrigin *origin);
 WEBKIT_API guint16
 webkit_security_origin_get_port     (WebKitSecurityOrigin *origin);
 
-WEBKIT_DEPRECATED gboolean
-webkit_security_origin_is_opaque    (WebKitSecurityOrigin *origin);
 
 WEBKIT_API gchar *
 webkit_security_origin_to_string    (WebKitSecurityOrigin *origin);
